@@ -48,9 +48,11 @@ jomo1rancat.MCMCchain <-
     Y.cat<-data.matrix(Y.cat)
     storage.mode(Y.cat) <- "numeric"    
     X<-data.matrix(X)
-    storage.mode(X) <- "numeric"    
+    storage.mode(X) <- "numeric" 
+    stopifnot(!any(is.na(X)))
     Z<-data.matrix(Z)
-    storage.mode(Z) <- "numeric"    
+    storage.mode(Z) <- "numeric"  
+    stopifnot(!any(is.na(Z)))
     clus <- matrix(as.integer(levels(clus))[clus], ncol=1)
     Y=cbind(Y.cat)
     Yi=cbind(matrix(0,nrow(Y.cat),(sum(Y.numcat)-length(Y.numcat))))
